# mouth2_oc
[![pypi version](https://img.shields.io/pypi/v/mouth2-oc.svg)](https://pypi.org/project/mouth2-oc) ![Custom License](https://img.shields.io/pypi/l/mouth2-oc.svg)

[body_oc](https://pypi.org/project/body-oc/) 2.0 service that handles outgoing
communications like emails and sms messages.

Please see [LICENSE](https://github.com/ouroboroscoding/mouth2/blob/main/LICENSE)
for further information.

# Requires
mouth2_oc requires python 3.10 or higher

# Install
```bash
pip install mouth2_oc
```

# RESTlike Documentation
For full documentation on the individual requests avaialable via the service,
check the [RESTlike](https://github.com/ouroboroscoding/mouth2/blob/main/rest.md)
docs.